:orphan:

:py:mod:`icclim._core.legacy`
=============================

.. py:module:: icclim._core.legacy


Subpackages
-----------
.. toctree::
   :titlesonly:
   :maxdepth: 3

   user_index/index.rst
